summaryrefslogtreecommitdiffstats
path: root/src/com
diff options
context:
space:
mode:
Diffstat (limited to 'src/com')
-rw-r--r--src/com/vaadin/demo/sampler/APIResource.java4
-rw-r--r--src/com/vaadin/demo/sampler/SamplerApplication.java4
-rw-r--r--src/com/vaadin/demo/sampler/features/commons/TooltipsExample.java2
-rw-r--r--src/com/vaadin/launcher/WidgetsetCompiler.java2
-rw-r--r--src/com/vaadin/terminal/gwt/server/AbstractApplicationServlet.java26
-rw-r--r--src/com/vaadin/tests/TestForMultipleStyleNames.java4
-rw-r--r--src/com/vaadin/tests/tickets/Ticket1975.java2
-rw-r--r--src/com/vaadin/tests/tickets/Ticket2022.java2
-rw-r--r--src/com/vaadin/ui/CustomLayout.java2
-rw-r--r--src/com/vaadin/ui/LoginForm.java4
10 files changed, 26 insertions, 26 deletions
diff --git a/src/com/vaadin/demo/sampler/APIResource.java b/src/com/vaadin/demo/sampler/APIResource.java
index f7138aac12..11024a5ebf 100644
--- a/src/com/vaadin/demo/sampler/APIResource.java
+++ b/src/com/vaadin/demo/sampler/APIResource.java
@@ -8,7 +8,7 @@ package com.vaadin.demo.sampler;
*/
public class APIResource extends NamedExternalResource {
- private static final String ITMILL_BASE = "http://toolkit.itmill.com/demo/doc/api/";
+ private static final String VAADIN_BASE = "http://toolkit.itmill.com/demo/doc/api/";
private static final String JAVA_BASE = "http://java.sun.com/javase/6/docs/api/";
private static final String SERVLET_BASE = "http://java.sun.com/products/servlet/2.5/docs/servlet-2_5-mr2";
private static final String PORTLET_BASE = "http://developers.sun.com/docs/jscreator/apis/portlet";
@@ -46,7 +46,7 @@ public class APIResource extends NamedExternalResource {
} else if (name.startsWith("java.") || name.startsWith("javax.")) {
return JAVA_BASE;
}
- return ITMILL_BASE;
+ return VAADIN_BASE;
}
private static String resolveName(Class clazz) {
diff --git a/src/com/vaadin/demo/sampler/SamplerApplication.java b/src/com/vaadin/demo/sampler/SamplerApplication.java
index bab73cd6a9..cf06d929e6 100644
--- a/src/com/vaadin/demo/sampler/SamplerApplication.java
+++ b/src/com/vaadin/demo/sampler/SamplerApplication.java
@@ -71,12 +71,12 @@ public class SamplerApplication extends Application {
*/
public static String getThemeBase() {
try {
- URI uri = new URI(APP_URL + "../ITMILL/themes/" + THEME_NAME + "/");
+ URI uri = new URI(APP_URL + "../VAADIN/themes/" + THEME_NAME + "/");
return uri.normalize().toString();
} catch (Exception e) {
System.err.println("Theme location could not be resolved:" + e);
}
- return "/ITMILL/themes/" + THEME_NAME + "/";
+ return "/VAADIN/themes/" + THEME_NAME + "/";
}
// Supports multiple browser windows
diff --git a/src/com/vaadin/demo/sampler/features/commons/TooltipsExample.java b/src/com/vaadin/demo/sampler/features/commons/TooltipsExample.java
index 932286df76..35c7613707 100644
--- a/src/com/vaadin/demo/sampler/features/commons/TooltipsExample.java
+++ b/src/com/vaadin/demo/sampler/features/commons/TooltipsExample.java
@@ -25,7 +25,7 @@ public class TooltipsExample extends VerticalLayout {
rich.setStyleName(Button.STYLE_LINK);
// add the tooltip:
rich
- .setDescription("<h2><img src=\"../ITMILL/themes/sampler/icons/comment_yellow.gif\"/>A richtext tooltip</h2>"
+ .setDescription("<h2><img src=\"../VAADIN/themes/sampler/icons/comment_yellow.gif\"/>A richtext tooltip</h2>"
+ "<ul>"
+ "<li>HTML formatting</li><li>Images<br/>"
+ "</li><li>etc...</li></ul>");
diff --git a/src/com/vaadin/launcher/WidgetsetCompiler.java b/src/com/vaadin/launcher/WidgetsetCompiler.java
index ecbd270d66..9496fe0640 100644
--- a/src/com/vaadin/launcher/WidgetsetCompiler.java
+++ b/src/com/vaadin/launcher/WidgetsetCompiler.java
@@ -14,7 +14,7 @@ import com.google.gwt.dev.GWTCompiler;
*
* A typical invocation would use e.g. the following arguments
*
- * "-out WebContent/ITMILL/widgetsets com.vaadin.terminal.gwt.DefaultWidgetSet"
+ * "-out WebContent/VAADIN/widgetsets com.vaadin.terminal.gwt.DefaultWidgetSet"
*
* In addition, larger memory usage settings for the VM should be used, e.g.
*
diff --git a/src/com/vaadin/tests/tickets/Ticket1975.java b/src/com/vaadin/tests/tickets/Ticket1975.java
index 1d35046475..9adc67f529 100644
--- a/src/com/vaadin/tests/tickets/Ticket1975.java
+++ b/src/com/vaadin/tests/tickets/Ticket1975.java
@@ -47,7 +47,7 @@ public class Ticket1975 extends Application {
}));
File f = new File(wc.getBaseDirectory().getAbsoluteFile()
- + "/ITMILL/themes/" + getTheme()
+ + "/VAADIN/themes/" + getTheme()
+ "/layouts/Ticket1975.html");
cl2 = new CustomLayout(new FileInputStream(f));
diff --git a/src/com/vaadin/tests/tickets/Ticket2022.java b/src/com/vaadin/tests/tickets/Ticket2022.java
index f88896a5f8..9dfcabc208 100644
--- a/src/com/vaadin/tests/tickets/Ticket2022.java
+++ b/src/com/vaadin/tests/tickets/Ticket2022.java
@@ -15,7 +15,7 @@ public class Ticket2022 extends Application {
// WebApplicationContext wac = ((WebApplicationContext) getContext());
// File f = new File(wac.getBaseDirectory().getAbsoluteFile()
- // + "/ITMILL/themes/" + getTheme() + "/layouts/Ticket2022.html");
+ // + "/VAADIN/themes/" + getTheme() + "/layouts/Ticket2022.html");
l = new CustomLayout("Ticket2022");
// try {
diff --git a/src/com/vaadin/ui/CustomLayout.java b/src/com/vaadin/ui/CustomLayout.java
index 6ec7986a29..3b923e5d08 100644
--- a/src/com/vaadin/ui/CustomLayout.java
+++ b/src/com/vaadin/ui/CustomLayout.java
@@ -269,7 +269,7 @@ public class CustomLayout extends AbstractLayout {
* Set the name of the template used to draw custom layout.
*
* With GWT-adapter, the template with name 'templatename' is loaded from
- * ITMILL/themes/themename/layouts/templatename.html. If the theme has not
+ * VAADIN/themes/themename/layouts/templatename.html. If the theme has not
* been set (with Application.setTheme()), themename is 'default'.
*
* @param templateName
diff --git a/src/com/vaadin/ui/LoginForm.java b/src/com/vaadin/ui/LoginForm.java
index 6474ff032e..a9f94bbf54 100644
--- a/src/com/vaadin/ui/LoginForm.java
+++ b/src/com/vaadin/ui/LoginForm.java
@@ -126,10 +126,10 @@ public class LoginForm extends CustomComponent {
protected byte[] getLoginHTML() {
String theme = getApplication().getMainWindow().getTheme();
- String guessedThemeUri = getApplication().getURL() + "ITMILL/themes/"
+ String guessedThemeUri = getApplication().getURL() + "VAADIN/themes/"
+ (theme == null ? "default" : theme) + "/styles.css";
String guessedThemeUri2 = getApplication().getURL()
- + "../ITMILL/themes/" + (theme == null ? "default" : theme)
+ + "../VAADIN/themes/" + (theme == null ? "default" : theme)
+ "/styles.css";
String appUri = getApplication().getURL().toString();
diff --git a/src/com/vaadin/terminal/gwt/server/AbstractApplicationServlet.java b/src/com/vaadin/terminal/gwt/server/AbstractApplicationServlet.java
index 029d28bf0f..52ac148e76 100644
--- a/src/com/vaadin/terminal/gwt/server/AbstractApplicationServlet.java
+++ b/src/com/vaadin/terminal/gwt/server/AbstractApplicationServlet.java
@@ -129,7 +129,7 @@ public abstract class AbstractApplicationServlet extends HttpServlet {
private static final String SERVLET_PARAMETER_PRODUCTION_MODE = "productionMode";
// Configurable parameter names
- private static final String PARAMETER_ITMILL_RESOURCES = "Resources";
+ private static final String PARAMETER_VAADIN_RESOURCES = "Resources";
private static final int DEFAULT_BUFFER_SIZE = 32 * 1024;
@@ -139,11 +139,11 @@ public abstract class AbstractApplicationServlet extends HttpServlet {
private static final String AJAX_UIDL_URI = "/UIDL";
- static final String THEME_DIRECTORY_PATH = "ITMILL/themes/";
+ static final String THEME_DIRECTORY_PATH = "VAADIN/themes/";
private static final int DEFAULT_THEME_CACHETIME = 1000 * 60 * 60 * 24;
- static final String WIDGETSET_DIRECTORY_PATH = "ITMILL/widgetsets/";
+ static final String WIDGETSET_DIRECTORY_PATH = "VAADIN/widgetsets/";
// Name of the default widget set, used if not specified in web.xml
private static final String DEFAULT_WIDGETSET = "com.vaadin.terminal.gwt.DefaultWidgetSet";
@@ -559,8 +559,8 @@ public abstract class AbstractApplicationServlet extends HttpServlet {
} else if (requestType == RequestType.OTHER) {
/*
- * TODO Should *any* request really create a new application
- * instance if none was found?
+ * TODO Shouldany request really create a new application instance
+ * if none was found?
*/
return createApplication(request);
@@ -889,12 +889,12 @@ public abstract class AbstractApplicationServlet extends HttpServlet {
}
if ((request.getContextPath() != null)
- && (request.getRequestURI().startsWith("/ITMILL/"))) {
- serveStaticResourcesInITMILL(request.getRequestURI(), response);
+ && (request.getRequestURI().startsWith("/VAADIN/"))) {
+ serveStaticResourcesInVAADIN(request.getRequestURI(), response);
return true;
} else if (request.getRequestURI().startsWith(
- request.getContextPath() + "/ITMILL/")) {
- serveStaticResourcesInITMILL(request.getRequestURI().substring(
+ request.getContextPath() + "/VAADIN/")) {
+ serveStaticResourcesInVAADIN(request.getRequestURI().substring(
request.getContextPath().length()), response);
return true;
}
@@ -903,14 +903,14 @@ public abstract class AbstractApplicationServlet extends HttpServlet {
}
/**
* Serve resources from ITMILL directory.
*
* @param request
* @param response
* @throws IOException
* @throws ServletException
*/
- private void serveStaticResourcesInITMILL(String filename,
+ private void serveStaticResourcesInVAADIN(String filename,
HttpServletResponse response) throws IOException, ServletException {
final ServletContext sc = getServletContext();
@@ -928,7 +928,7 @@ public abstract class AbstractApplicationServlet extends HttpServlet {
.println("Requested resource ["
+ filename
+ "] not found from filesystem or through class loader."
- + " Add widgetset and/or theme JAR to your classpath or add files to WebContent/ITMILL folder.");
+ + " Add widgetset and/or theme JAR to your classpath or add files to WebContent/VAADIN folder.");
response.setStatus(404);
return;
}
@@ -1121,7 +1121,7 @@ public abstract class AbstractApplicationServlet extends HttpServlet {
final String widgetsetPath = getWidgetsetLocation(request);
final String staticFilePath = getApplicationOrSystemProperty(
- PARAMETER_ITMILL_RESOURCES, widgetsetPath);
+ PARAMETER_VAADIN_RESOURCES, widgetsetPath);
// Default theme does not use theme URI
String themeUri = null;
@@ -903,14 +903,14 @@ public abstract class AbstractApplicationServlet extends HttpServlet {
}
/**
- * Serve resources from ITMILL directory.
+ * Serve resources from VAADIN directory.
*
* @param request
diff --git a/src/com/vaadin/tests/TestForMultipleStyleNames.java b/src/com/vaadin/tests/TestForMultipleStyleNames.java
index a936da4218..a0facecd56 100644
--- a/src/com/vaadin/tests/TestForMultipleStyleNames.java
+++ b/src/com/vaadin/tests/TestForMultipleStyleNames.java
@@ -17,7 +17,7 @@ import com.vaadin.ui.OrderedLayout;
import com.vaadin.ui.TwinColSelect;
/**
* TODO: Note you need to add Theme under WebContent/ITMILL/Themes/mytheme in
* order to see actual visible results on the browser. Currently changes are
* visible only by inspecting DOM.
*
@@ -44,7 +44,7 @@ public class TestForMultipleStyleNames extends CustomComponent implements
main.addComponent(new Label(
"TK5 supports multiple stylenames for components."));
main.addComponent(new Label("Note you need to add Theme under"
- + " WebContent/ITMILL/Themes/mytheme"
+ + " WebContent/VAADIN/Themes/mytheme"
+ " in order to see actual visible results"
+ " on the browser. Currently changes are"
+ " visible only by inspecting DOM."));
@@ -17,7 +17,7 @@ import com.vaadin.ui.OrderedLayout;
import com.vaadin.ui.TwinColSelect;
/**
- * TODO: Note you need to add Theme under WebContent/ITMILL/Themes/mytheme in
+ * TODO: Note you need to add Theme under WebContent/VAADIN/Themes/mytheme in
* order to see actual visible results on the browser. Currently changes are
* visible only by inspecting DOM.